@@ -1,22 +1,11 @@
-/* This file is part of libkdbus
+/*
+    This file is part of libkdbus
 
-   Copyright (c) 1999 Waldo Bastian <bastian@kde.org>
-   Copyright (c) 2011 David Faure <faure@kde.org>
-   Copyright (c) 2011 Kevin Ottens <ervin@kde.org>
+    SPDX-FileCopyrightText: 1999 Waldo Bastian <bastian@kde.org>
+    SPDX-FileCopyrightText: 2011 David Faure <faure@kde.org>
+    SPDX-FileCopyrightText: 2011 Kevin Ottens <ervin@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License version 2 as published by the Free Software Foundation.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #include <QCoreApplication>
@@ -139,8 +128,8 @@ int main(int argc, char *argv[])
 
     KDBusService service(KDBusService::Unique);
     TestObject testObject(&service);
-    QObject::connect(&service, SIGNAL(activateRequested(QStringList, QString)),
-                     &testObject, SLOT(slotActivateRequested(QStringList, QString)));
+    QObject::connect(&service, SIGNAL(activateRequested(QStringList,QString)),
+                     &testObject, SLOT(slotActivateRequested(QStringList,QString)));
 
     // Testcase for the problem coming from the old fork-on-startup solution:
     // the "Activate" D-Bus call would time out if the app took too much time
